@@ -1,17 +1,17 @@
-## ----setup, include = FALSE----------------------------------------------
+## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
   fig.keep = "all",
   out.width = '75%',
-  dev = c("png", "svg")
+  eval = !identical(Sys.getenv("NOT_CRAN"), "true")
 )
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(texPreview)
 library(slickR)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 objpath <- file.path(getwd(),"slickr_files/figure-html")
 
@@ -24,13 +24,13 @@ tex_opts$set(
   imgFormat  = 'png' # return png images
   )
 
-## ----kable---------------------------------------------------------------
+## ----kable--------------------------------------------------------------------
 
 knitr::kable(mtcars,'latex')%>%
   texPreview::tex_preview(stem = 'kable-1')
 
 
-## ----tex-----------------------------------------------------------------
+## ----tex----------------------------------------------------------------------
 
 tab='
 \\begin{tabular}{llr}
@@ -50,7 +50,7 @@ Armadillo & frozen      & 8.99       \\\\
 tab%>%
   texPreview::tex_preview(stem = 'tex-1')
 
-## ----testOut3------------------------------------------------------------
+## ----testOut3-----------------------------------------------------------------
 
   slickR::slickR(
     list.files(objpath,full.names = TRUE,pattern = 'png'),
